@@ -2,8 +2,8 @@
 from {{app_settings_module}} import *
 from {{local_prefix}}.settings import *
 
-import logging
-logging.getLogger('weasyprint').setLevel("ERROR") # see #1462
+# import logging
+# logging.getLogger('weasyprint').setLevel("ERROR") # see #1462
 
 
 class Site(Site):
@@ -15,7 +15,7 @@ class Site(Site):
     {% if languages %}
     languages = '{{languages}}'
     {% endif %}
-    use_linod = {{linod}}
+    use_linod = True
     default_ui = '{{front_end}}'
 
     def get_plugin_configs(self):
@@ -27,8 +27,10 @@ SITE = Site(globals())
 
 {% if server_domain == "localhost" %}
 DEBUG = True
+# ALLOWED_HOSTS = ['{{server_domain}}']
 {% else %}
-DEBUG = False
+DEBUG = False  # "{{server_domain}}"
+ALLOWED_HOSTS = ['{{server_domain}}']
 {% endif %}
 
 SECRET_KEY = '{{secret_key}}'
@@ -52,5 +54,3 @@ DATABASES = {
 }
 
 EMAIL_SUBJECT_PREFIX = '[{{prjname}}] '
-
-ALLOWED_HOSTS = ['{{server_domain}}']
